﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Timelines;
using Infragistics.Controls;
using System.ComponentModel;
using IGStockAnnotator.ViewModel;

namespace IGStockAnnotator
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        //The binding used in the synchronisation
        //The Mode is set to TwoWay so that if one of the zoombars changes -> all change
        private Binding _binding = new Binding { ElementName = "zoombar", Path = new PropertyPath("Range"), Mode = BindingMode.TwoWay };
        
        public MainWindow()
        {
            InitializeComponent();
            Loaded += new RoutedEventHandler(MainWindow_Loaded);
        }


        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            //binding the timeline and chart zoombars
            xamDataChart1.HorizontalZoombar.SetBinding(XamZoombar.RangeProperty, _binding);
            xamTimeline1.Zoombar.SetBinding(XamZoombar.RangeProperty, _binding);
        }

        private void xamDataGrid_RecordActivateed(object sender, Infragistics.Windows.DataPresenter.Events.RecordActivatedEventArgs e)
        {
            //set the annotation textbox to the detials of the selected record in the grid
            if(!e.Record.IsSpecialRecord)
                annotationTextTb.Text = ((e.Record as Infragistics.Windows.DataPresenter.DataRecord).DataItem as EventAnnotation).Details;
        }

        private void EventDetails_Click(object sender, MouseButtonEventArgs e)
        {
            //closes the details panel once it's clicked
            DependencyObject visual = sender as DependencyObject;
            EventDetails details = null;

            while (visual != null && details == null)
            {
                //find the event details element
                while(!(visual is EventDetails))
                    visual = VisualTreeHelper.GetParent(visual);
    
                details = visual as EventDetails;

                if (details != null)
                {
                    //hide the details panel
                    details.Visibility = Visibility.Collapsed;

                    DateTimeAxis axis = this.xamTimeline1.Axis as DateTimeAxis;
                    axis.SelectedTime = axis.SelectedTime.AddMilliseconds(1);
                }
            }
        }

        private void EventTitle_Clicked(object sender, MouseButtonEventArgs e)
        {
            //event point clicked - display the details of the clicked annotation in the textbox
            if (sender is Grid)
            {
                EventAnnotation ea = (sender as Grid).DataContext as EventAnnotation;
                annotationTextTb.Text = ea.Details;
            }
            //event title clicked - display the details of the clicked annotation in the textbox
            else
                annotationTextTb.Text = ((EventTitle)sender).Details.ToString();
        }
    }
}
